@@ -15,13 +15,13 @@ import sys
 from typing import Dict, List
 
 from .literals import (
-    ComponentType,
-    EbsVolumeType,
-    ImageStatus,
-    ImageType,
-    PipelineExecutionStartCondition,
-    PipelineStatus,
-    Platform,
+    ComponentTypeType,
+    EbsVolumeTypeType,
+    ImageStatusType,
+    ImageTypeType,
+    PipelineExecutionStartConditionType,
+    PipelineStatusType,
+    PlatformType,
 )
 
 if sys.version_info >= (3, 8):
@@ -168,9 +168,9 @@ ComponentSummaryTypeDef = TypedDict(
         "arn": str,
         "name": str,
         "version": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "supportedOsVersions": List[str],
-        "type": ComponentType,
+        "type": ComponentTypeType,
         "owner": str,
         "description": str,
         "changeDescription": str,
@@ -188,8 +188,8 @@ ComponentTypeDef = TypedDict(
         "version": str,
         "description": str,
         "changeDescription": str,
-        "type": ComponentType,
-        "platform": Platform,
+        "type": ComponentTypeType,
+        "platform": PlatformType,
         "supportedOsVersions": List[str],
         "owner": str,
         "data": str,
@@ -208,9 +208,9 @@ ComponentVersionTypeDef = TypedDict(
         "name": str,
         "version": str,
         "description": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "supportedOsVersions": List[str],
-        "type": ComponentType,
+        "type": ComponentTypeType,
         "owner": str,
         "dateCreated": str,
     },
@@ -246,7 +246,7 @@ ContainerRecipeSummaryTypeDef = TypedDict(
         "arn": str,
         "containerType": Literal["DOCKER"],
         "name": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "owner": str,
         "parentImage": str,
         "dateCreated": str,
@@ -262,7 +262,7 @@ ContainerRecipeTypeDef = TypedDict(
         "containerType": Literal["DOCKER"],
         "name": str,
         "description": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "owner": str,
         "version": str,
         "components": List["ComponentConfigurationTypeDef"],
@@ -493,7 +493,7 @@ EbsInstanceBlockDeviceSpecificationTypeDef = TypedDict(
         "kmsKeyId": str,
         "snapshotId": str,
         "volumeSize": int,
-        "volumeType": EbsVolumeType,
+        "volumeType": EbsVolumeTypeType,
     },
     total=False,
 )
@@ -621,7 +621,7 @@ ImagePipelineTypeDef = TypedDict(
         "arn": str,
         "name": str,
         "description": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "enhancedImageMetadataEnabled": bool,
         "imageRecipeArn": str,
         "containerRecipeArn": str,
@@ -629,7 +629,7 @@ ImagePipelineTypeDef = TypedDict(
         "distributionConfigurationArn": str,
         "imageTestsConfiguration": "ImageTestsConfigurationTypeDef",
         "schedule": "ScheduleTypeDef",
-        "status": PipelineStatus,
+        "status": PipelineStatusType,
         "dateCreated": str,
         "dateUpdated": str,
         "dateLastRun": str,
@@ -644,7 +644,7 @@ ImageRecipeSummaryTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "owner": str,
         "parentImage": str,
         "dateCreated": str,
@@ -657,10 +657,10 @@ ImageRecipeTypeDef = TypedDict(
     "ImageRecipeTypeDef",
     {
         "arn": str,
-        "type": ImageType,
+        "type": ImageTypeType,
         "name": str,
         "description": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "owner": str,
         "version": str,
         "components": List["ComponentConfigurationTypeDef"],
@@ -676,7 +676,7 @@ ImageRecipeTypeDef = TypedDict(
 ImageStateTypeDef = TypedDict(
     "ImageStateTypeDef",
     {
-        "status": ImageStatus,
+        "status": ImageStatusType,
         "reason": str,
     },
     total=False,
@@ -687,9 +687,9 @@ ImageSummaryTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": ImageType,
+        "type": ImageTypeType,
         "version": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "osVersion": str,
         "state": "ImageStateTypeDef",
         "owner": str,
@@ -713,10 +713,10 @@ ImageTypeDef = TypedDict(
     "ImageTypeDef",
     {
         "arn": str,
-        "type": ImageType,
+        "type": ImageTypeType,
         "name": str,
         "version": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "enhancedImageMetadataEnabled": bool,
         "osVersion": str,
         "state": "ImageStateTypeDef",
@@ -739,9 +739,9 @@ ImageVersionTypeDef = TypedDict(
     {
         "arn": str,
         "name": str,
-        "type": ImageType,
+        "type": ImageTypeType,
         "version": str,
-        "platform": Platform,
+        "platform": PlatformType,
         "osVersion": str,
         "owner": str,
         "dateCreated": str,
@@ -1033,7 +1033,7 @@ ScheduleTypeDef = TypedDict(
     {
         "scheduleExpression": str,
         "timezone": str,
-        "pipelineExecutionStartCondition": PipelineExecutionStartCondition,
+        "pipelineExecutionStartCondition": PipelineExecutionStartConditionType,
     },
     total=False,
 )
